# Build UIs with `Interact` API

These How-to pages provide solutions for common tasks related to the use of Panel `interact`.

::::{grid} 1 2 2 3
:gutter: 1 1 1 2

:::{grid-item-card} {octicon}`pulse;2.5em;sd-mr-1 sd-animate-grow50` Generate Widgets for Function Arguments
:link: interact_basics
:link-type: doc

How to generate widgets for function arguments with Panel `interact`.
:::

:::{grid-item-card} {octicon}`number;2.5em;sd-mr-1 sd-animate-grow50` Use abbreviations to generate widgets
:link: interact_abbreviations
:link-type: doc

How to use abbreviations to create widgets with Panel `interact`.
:::

:::{grid-item-card} {octicon}`project;2.5em;sd-mr-1 sd-animate-grow50` Customize Layout with `Interact`
:link: interact_layout
:link-type: doc

How to customize the layout of the widgets and display from the output of Panel `interact`.
:::

:::{grid-item-card} {octicon}`lock;2.5em;sd-mr-1 sd-animate-grow50` Fix Values with `Interact`
:link: interact_fix_values
:link-type: doc

How to fix the value for certain arguments with Panel `interact`.
:::

:::{grid-item-card} {octicon}`blocked;2.5em;sd-mr-1 sd-animate-grow50` Disable Continuous Updates with `Interact`
:link: interact_throttle
:link-type: doc

How to disable continuous updating with Panel `interact`.
:::

::::

```{toctree}
:titlesonly:
:hidden:
:maxdepth: 2

interact_basics
interact_abbreviations
interact_layout
interact_fix_values
interact_throttle
```
